@@ -182,6 +182,7 @@ mark_balls (int x, int y)
 		ball_timeout_id = gtk_timeout_add (100, move_tagged_balls, 0);
 		b = g_strdup_printf ("%.2d", tagged_count);
 		gtk_label_set_text (GTK_LABEL(markedw), b);
+		g_free (b);
 	} else
 		gtk_label_set_text (GTK_LABEL(markedw), "00");
 }
@@ -252,6 +253,7 @@ set_score (int new_score)
 	score = new_score;
 	b = g_strdup_printf ("%.5d", score);
 	gtk_label_set_text (GTK_LABEL(scorew), b);
+	g_free (b);
 }
 
 static void
@@ -386,6 +388,7 @@ load_scenario (char *fname)
 	char *tmp, *fn;
         GdkColor bgcolor;
         GdkImage *tmpimage;
+	int i, j;
     
 	g_return_if_fail (fname != NULL);
 
@@ -439,6 +442,17 @@ load_scenario (char *fname)
 	g_free( fn );
 
 	nstones = gdk_pixbuf_get_width (image) / STONE_SIZE;
+	for (i = 0; i < STONE_COLS; i++)
+	{
+		for (j = 0; j < STONE_LINES; j++)
+		{
+			if (sync_stones) {
+				field[i][j].frame = 0;
+			} else {
+				field[i][j].frame %= nstones;
+			}
+		}
+	}
 /*	ncolors = image->rgb_height / STONE_SIZE; */
 	ncolors = 3;
 
@@ -670,7 +684,7 @@ GnomeUIInfo gamemenu[] = {
 
 	GNOMEUIINFO_SEPARATOR,
 
-        GNOMEUIINFO_MENU_EXIT_ITEM(game_quit_callback, NULL),
+        GNOMEUIINFO_MENU_QUIT_ITEM(game_quit_callback, NULL),
 
 	GNOMEUIINFO_END
 };
@@ -682,7 +696,7 @@ GnomeUIInfo settingsmenu[] = {
 };
 
 GnomeUIInfo helpmenu[] = {
-        GNOMEUIINFO_HELP("samegnome"),
+        GNOMEUIINFO_HELP("same-gnome"),
 
 	GNOMEUIINFO_MENU_ABOUT_ITEM(game_about_callback, NULL),
 
@@ -788,7 +802,11 @@ main (int argc, char *argv [])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_init_with_popt_table ("same-gnome", VERSION, argc, argv, options, 0, NULL);
+        gnome_program_init ("same-gnome", VERSION,
+                             LIBGNOMEUI_MODULE,
+                             argc, argv,
+                             GNOME_PARAM_POPT_TABLE, options,
+                             GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gsame.png");
 	client= gnome_master_client ();
